@@ -100,9 +100,8 @@ int main(int argc, char* argv[])
                        QStringLiteral("Audio Tag Editor"), KAboutLicense::GPL,
                        QStringLiteral("(c) 2003-" RELEASE_YEAR " Urs Fleisch"),
                        QString(),
-                       QStringLiteral("http://kid3.sourceforge.net"),
-                       QStringLiteral("ufleisch@users.sourceforge.net"));
-  aboutData.setOrganizationDomain(QByteArray("sourceforge.net"));
+                       QStringLiteral("https://kid3.kde.org"));
+  aboutData.setOrganizationDomain(QByteArray("kde.org"));
   aboutData.addAuthor(QStringLiteral("Urs Fleisch"), QString(),
                       QStringLiteral("ufleisch@users.sourceforge.net"));
   aboutData.setProductName(QByteArray("kid3"));
@@ -159,11 +158,11 @@ int main(int argc, char* argv[])
     kid3->show();
 
     if (parser.positionalArguments().count()) {
-      kid3->confirmedOpenDirectory(parser.positionalArguments());
+      kid3App->openDirectory(parser.positionalArguments());
     } else if (FileConfig::instance().loadLastOpenedFile() &&
                !FileConfig::instance().lastOpenedFile().isEmpty()) {
-      kid3->confirmedOpenDirectory(QStringList()
-                                   << FileConfig::instance().lastOpenedFile());
+      kid3App->openDirectory(QStringList()
+                             << FileConfig::instance().lastOpenedFile());
     }
   }
 
