@@ -61,6 +61,12 @@ public:
    */
   virtual void initActions() override;
 
+  /**
+   * Get keyboard shortcuts.
+   * @return mapping of action names to key sequences.
+   */
+  virtual QMap<QString, QKeySequence> shortcutsMap() const override;
+
   /**
    * Add directory to recent files list.
    *
