@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 19-Mar-2011
  *
- * Copyright (C) 2011-2014  Urs Fleisch
+ * Copyright (C) 2011-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef DIRPROXYMODEL_H
-#define DIRPROXYMODEL_H
+#pragma once
 
 #include <QSortFilterProxyModel>
 
@@ -39,12 +38,14 @@ public:
    *
    * @param parent parent object
    */
-  explicit DirProxyModel(QObject* parent = 0);
+  explicit DirProxyModel(QObject* parent = nullptr);
 
   /**
-   * Reset the model.
+   * Get item flags.
+   * @param index index of item
+   * @return default flags without editable.
    */
-  void resetModel();
+  virtual Qt::ItemFlags flags(const QModelIndex& index) const override;
 
 protected:
   /**
@@ -55,7 +56,7 @@ protected:
    *
    * @return true to include row.
    */
-  virtual bool filterAcceptsRow(int srcRow, const QModelIndex& srcParent) const;
+  virtual bool filterAcceptsRow(int srcRow, const QModelIndex& srcParent) const override;
 
   /**
    * Sort comparison function.
@@ -63,7 +64,5 @@ protected:
    * @param right index of right item in source model
    * @return true if left is less than right.
    */
-  virtual bool lessThan(const QModelIndex& left, const QModelIndex& right) const;
+  virtual bool lessThan(const QModelIndex& left, const QModelIndex& right) const override;
 };
-
-#endif // DIRPROXYMODEL_H
