@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 21 Mar 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -28,7 +28,9 @@
 
 #include <QCoreApplication>
 
-static const struct {
+namespace {
+
+const struct {
   const char* text;
   int code;
 } codes[] = {
@@ -75,8 +77,9 @@ static const struct {
   { QT_TRANSLATE_NOOP("@default", "audio file ends"), 0xfe }
 };
 
-static const int numCodes = static_cast<int>(sizeof codes / sizeof codes[0]);
+const int numCodes = static_cast<int>(sizeof codes / sizeof codes[0]);
 
+}
 
 /**
  * Get string representation.
@@ -89,8 +92,8 @@ QString EventTimeCode::toString() const
       return QString::fromLatin1(codes[i].text);
     }
   }
-  return QString(QLatin1String("reserved for future use %1")).
-      arg(m_code, 2, 16, QLatin1Char('0'));
+  return QString(QLatin1String("reserved for future use %1"))
+      .arg(m_code, 2, 16, QLatin1Char('0'));
 }
 
 /**
@@ -106,8 +109,8 @@ QString EventTimeCode::toTranslatedString() const
   }
   const char* const reservedForFutureUseStr =
       QT_TRANSLATE_NOOP("@default", "reserved for future use %1");
-  return QCoreApplication::translate("@default", reservedForFutureUseStr).
-      arg(m_code, 2, 16, QLatin1Char('0'));
+  return QCoreApplication::translate("@default", reservedForFutureUseStr)
+      .arg(m_code, 2, 16, QLatin1Char('0'));
 }
 
 /**
@@ -159,6 +162,7 @@ EventTimeCode EventTimeCode::fromIndex(int index)
 QStringList EventTimeCode::getTranslatedStrings()
 {
   QStringList strings;
+  strings.reserve(numCodes);
   for (int i = 0; i < numCodes; ++i) {
     strings << QCoreApplication::translate("@default", codes[i].text);
   }
