@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 23 Jan 2008
  *
- * Copyright (C) 2008-2013  Urs Fleisch
+ * Copyright (C) 2008-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -29,25 +29,57 @@
 
 #include "expressionparser.h"
 
+namespace {
+
+/**
+ * Convert a string to a boolean.
+ *
+ * @param str string
+ * @param b   the boolean is returned here
+ *
+ * @return true if ok.
+ */
+bool stringToBool(const QString& str, bool& b)
+{
+  if (str == QLatin1String("1") || str == QLatin1String("true") ||
+      str == QLatin1String("on") || str == QLatin1String("yes")) {
+    b = true;
+    return true;
+  } else if (str == QLatin1String("0") || str == QLatin1String("false") ||
+             str == QLatin1String("off") || str == QLatin1String("no")) {
+    b = false;
+    return true;
+  }
+  return false;
+}
+
+/**
+ * Convert a boolean to a string.
+ *
+ * @param b boolean to convert
+ *
+ * @return "1" or "0".
+ */
+QString boolToString(bool b)
+{
+  return b ? QLatin1String("1") : QLatin1String("0");
+}
+
+}
+
 /**
  * Constructor.
  *
  * @param operators additional operators (besides not, and, or),
  *                  highest priority first
  */
-ExpressionParser::ExpressionParser(QStringList operators) :
-  m_operators(operators << QLatin1String("not") << QLatin1String("and") << QLatin1String("or")),
+ExpressionParser::ExpressionParser(QStringList operators) : // clazy:exclude=function-args-by-ref
+  m_operators(operators << QLatin1String("not") << QLatin1String("and")
+                        << QLatin1String("or")),
   m_error(false)
 {
 }
 
-/**
- * Destructor.
- */
-ExpressionParser::~ExpressionParser()
-{
-}
-
 /**
  * Compare operator priority.
  *
@@ -101,7 +133,8 @@ void ExpressionParser::tokenizeRpn(const QString& expr)
         // skip quoted string
         end = begin + 1;
         while (end < len &&
-               !(expr[end] == QLatin1Char('"') && (end <= 0 || expr[end - 1] != QLatin1Char('\\')))) {
+               !(expr[end] == QLatin1Char('"') &&
+                 (end <= 0 || expr[end - 1] != QLatin1Char('\\')))) {
           ++end;
         }
         token = expr.mid(begin + 1, end - begin - 1);
@@ -110,7 +143,8 @@ void ExpressionParser::tokenizeRpn(const QString& expr)
       } else {
         // skip spaces
         end = begin;
-        while (end < len && expr[end] != QLatin1Char(' ') && expr[end] != QLatin1Char(')')) {
+        while (end < len && expr[end] != QLatin1Char(' ') &&
+               expr[end] != QLatin1Char(')')) {
           ++end;
         }
         token = expr.mid(begin, end - begin);
@@ -136,40 +170,7 @@ void ExpressionParser::tokenizeRpn(const QString& expr)
     operatorStack.pop_back();
     m_rpnStack.push_back(lastOp);
   }
-  m_rpnIterator = m_rpnStack.begin();
-}
-
-
-/**
- * Convert a string to a boolean.
- *
- * @param str string
- * @param b   the boolean is returned here
- *
- * @return true if ok.
- */
-static bool stringToBool(const QString& str, bool& b)
-{
-  if (str == QLatin1String("1") || str == QLatin1String("true") || str == QLatin1String("on") || str == QLatin1String("yes")) {
-    b = true;
-    return true;
-  } else if (str == QLatin1String("0") || str == QLatin1String("false") || str == QLatin1String("off") || str == QLatin1String("no")) {
-    b = false;
-    return true;
-  }
-  return false;
-}
-
-/**
- * Convert a boolean to a string.
- *
- * @param b boolean to convert
- *
- * @return "1" or "0".
- */
-static QString boolToString(bool b)
-{
-  return b ? QLatin1String("1") : QLatin1String("0");
+  m_rpnIterator = m_rpnStack.constBegin();
 }
 
 /**
@@ -177,7 +178,7 @@ static QString boolToString(bool b)
  */
 void ExpressionParser::clearEvaluation()
 {
-  m_rpnIterator = m_rpnStack.begin();
+  m_rpnIterator = m_rpnStack.constBegin();
   m_varStack.clear();
   m_error = false;
 }
@@ -249,7 +250,7 @@ bool ExpressionParser::popTwoBools(bool& var1, bool& var2)
  */
 bool ExpressionParser::evaluate(QString& op, QString& var1, QString& var2)
 {
-  while (m_rpnIterator != m_rpnStack.end()) {
+  while (m_rpnIterator != m_rpnStack.constEnd()) {
     QString token = *m_rpnIterator++;
     if (token == QLatin1String("and")) {
       bool b1, b2;
