@@ -99,11 +99,40 @@ public:
     FT_ReleaseDate,
     FT_Rating,
     FT_Work,
-    FT_LastFrame = FT_Work,
+    FT_Custom1,
+    FT_Custom2,
+    FT_Custom3,
+    FT_Custom4,
+    FT_Custom5,
+    FT_Custom6,
+    FT_Custom7,
+    FT_Custom8,
+    FT_LastFrame = FT_Custom8,
     FT_Other,
     FT_UnknownFrame
   };
 
+  /** Maximum number of custom frame names. */
+  static const int NUM_CUSTOM_FRAME_NAMES = FT_LastFrame - FT_Custom1 + 1;
+
+  /**
+   * Check if a frame type is a custom frame.
+   * @param type frame type
+   * @return true if @a type is a custom frame type.
+   */
+  static constexpr bool isCustomFrameType(Type type) {
+    return type >= FT_Custom1 && type <= FT_LastFrame;
+  }
+
+  /**
+   * Check if a frame type is a custom frame or FT_Other
+   * @param type frame type
+   * @return true if @a type is a custom frame type or FT_Other.
+   */
+  static constexpr bool isCustomFrameTypeOrOther(Type type) {
+    return type >= FT_Custom1 && type <= FT_Other;
+  }
+
   /**
    * Types of fields in a frame, must be the same as id3lib's ID3_FieldID.
    **/
@@ -373,6 +402,18 @@ public:
      */
     static const char* const* getContentTypeNames();
 
+    /**
+     * Compare two field lists in a tolerant way.
+     * This function can be used instead of the standard QList equality
+     * operator if the field lists can be from different tag formats, which
+     * may not all support the same field types.
+     * @param fl1 first field list
+     * @param fl2 second field list
+     * @return true if they are similar enough.
+     */
+    static bool fuzzyCompareFieldLists(const QList<Field>& fl1,
+                                       const QList<Field>& fl2);
+
   };
 
   /** list of fields. */
@@ -645,6 +686,20 @@ public:
    */
   void setValueFromFieldList();
 
+  /**
+   * Read value text from file.
+   * @param fileName name of data file
+   * @return true if file read and value set.
+   */
+  bool setValueFromFile(const QString& fileName);
+
+  /**
+   * Save value text to a file.
+   * @param fileName name of data file to save
+   * @return true if saved.
+   */
+  bool writeValueToFile(const QString& fileName) const;
+
   /**
    * Set a field in the field list from the value.
    */
@@ -799,6 +854,66 @@ public:
    */
   static QString getNameForTranslatedFrameName(const QString& name);
 
+  /**
+   * Get internal frame ID of non unified frame for a translated display name.
+   * @param name translated display name
+   * @return internal frame ID, e.g. "SYLT", "keyw" of non unified frame,
+   *         null if @a name is not the name of a supported non unified frame.
+   */
+  static QByteArray getFrameIdForTranslatedFrameName(const QString& name);
+
+  /**
+   * Get the internal name for a custom frame.
+   * @param type custom frame type (FT_Custom1..FT_LastFrame)
+   * @return custom frame name, empty if not used.
+   */
+  static QByteArray getNameForCustomFrame(Frame::Type type);
+
+  /**
+   * Get type of frame from custom frame name.
+   * @param name custom frame name
+   * @return type, FT_Other if no custom frame with @a name exists.
+   */
+  static Frame::Type getTypeFromCustomFrameName(const QByteArray& name);
+
+  /**
+   * Set the internal names for all custom frames.
+   * The number of custom frames is limited. The internal vector will be resized
+   * to fit the fixed number of custom frames.
+   *
+   * @param customNames names for the custom frame types (FT_Custom1...),
+   * leading '!' will be removed from the names
+   * @return true if custom frame names were changed.
+   */
+  static bool setNamesForCustomFrames(const QStringList& customNames);
+
+  /**
+   * Get the names for all custom frames.
+   * The returned list does not contain empty names.
+   *
+   * @return names for the custom frame types (FT_Custom1, ...).
+   */
+  static QStringList getNamesForCustomFrames();
+
+  /**
+   * Convert frame index to a negative index used for a second collection.
+   * This can be a collection containing picture frames, the mapping is
+   * -1 -> -1, 0 -> -2, 1 -> -3, 2 -> -4, ...
+   * @param index positive index, -1 is the unknown index
+   * @return negative index <= -1.
+   */
+  static int toNegativeIndex(int index) { return -2 - index; }
+
+  /**
+   * Convert negative index used for a second collection to a frame index.
+   * This can be used to get the index of a collection containing picture
+   * frames, the mapping is
+   * -1 -> -1, -2 -> 0, -3 -> 1, -4 -> 2, ...
+   * @param negativeIndex negative index, -1 is the unknown index
+   * @return frame negative >= -1.
+   */
+  static int fromNegativeIndex(int negativeIndex) { return -2 - negativeIndex; }
+
 private:
   friend class TaggedFile;
 
