@@ -27,7 +27,7 @@
 #include "framenotice.h"
 #include <QCoreApplication>
 #include <QSet>
-#include <QRegExp>
+#include <QRegularExpression>
 #include "frame.h"
 
 namespace {
@@ -52,8 +52,13 @@ bool isDayMonth(const QString& str)
   if (str.length() != 4)
     return false;
 
+#if QT_VERSION >= 0x060000
+  int day = str.left(2).toInt();
+  int month = str.mid(2).toInt();
+#else
   int day = str.leftRef(2).toInt();
   int month = str.midRef(2).toInt();
+#endif
   return !(day < 1 || day > 31 || month < 1 || month > 12);
 }
 
@@ -62,8 +67,13 @@ bool isHourMinute(const QString& str)
   if (str.length() != 4)
     return false;
 
+#if QT_VERSION >= 0x060000
+  int hour = str.left(2).toInt();
+  int minute = str.mid(2).toInt();
+#else
   int hour = str.leftRef(2).toInt();
   int minute = str.midRef(2).toInt();
+#endif
   return !(hour < 0 || hour > 23 || minute < 0 || minute > 59);
 }
 
@@ -109,7 +119,7 @@ bool isIsrc(const QString& str)
 
 bool isIsoDateTime(const QString& str)
 {
-  return FrameNotice::isoDateTimeRexExp().exactMatch(str);
+  return FrameNotice::isoDateTimeRexExp().match(str).hasMatch();
 }
 
 bool isMusicalKey(const QString& str)
@@ -123,7 +133,11 @@ bool isMusicalKey(const QString& str)
   const QChar lastChar = str.at(len - 1);
   if (lastChar == QLatin1Char('A') || lastChar == QLatin1Char('B')) {
     bool ok;
+#if QT_VERSION >= 0x060000
+    int nr = str.left(len - 1).toInt(&ok);
+#else
     int nr = str.leftRef(len - 1).toInt(&ok);
+#endif
     if (ok && nr >= 1 && nr <= 12) {
       return true;
     }
@@ -200,16 +214,16 @@ QString FrameNotice::getDescription() const
  * Get regular expression to validate an ISO 8601 date/time.
  * @return regular expression matching ISO date/time and periods.
  */
-const QRegExp& FrameNotice::isoDateTimeRexExp()
+const QRegularExpression& FrameNotice::isoDateTimeRexExp()
 {
-  static const QRegExp isoDateRe(QLatin1String(
+  static const QRegularExpression isoDateRe(QLatin1String(
     // This is a simplified regular expression from
     // http://www.pelagodesign.com/blog/2009/05/20/iso-8601-date-validation-that-doesnt-suck/
     // relaxed to allow appending any string after a slash, so that ISO 8601
     // periods of time can by entered while still providing sufficient validation.
-    "(\\d{4})(-((0[1-9]|1[0-2])(-([12]\\d|0[1-9]|3[01]))?)(T((([01]\\d|2[0-3])"
+    "^(\\d{4})(-((0[1-9]|1[0-2])(-([12]\\d|0[1-9]|3[01]))?)(T((([01]\\d|2[0-3])"
     "(:[0-5]\\d)?|24:00))?(:[0-5]\\d([\\.,]\\d+)?)?"
-    "([zZ]|([\\+-])([01]\\d|2[0-3]):?([0-5]\\d)?)?)?(/.*)?)?"
+    "([zZ]|([\\+-])([01]\\d|2[0-3]):?([0-5]\\d)?)?)?(/.*)?)?$"
   ));
   return isoDateRe;
 }
