@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Jan 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,9 +24,57 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "debugutils.h"
+#include <QMetaObject>
+#include <QMetaMethod>
+
+/**
+ * Constructor.
+ * @param parent parent object
+ */
+DebugUtils::SignalEmissionDumper::SignalEmissionDumper(QObject* parent)
+  : QObject(parent)
+{
+}
+
 #ifndef QT_NO_DEBUG
 
-#include "debugutils.h"
+/**
+ * Monitor signal emissions of object
+ * @param obj object to monitor
+ */
+void DebugUtils::SignalEmissionDumper::connectObject(QObject* obj)
+{
+  const QMetaObject* metaObject = obj->metaObject();
+  for (int i = 0; i < metaObject->methodCount(); ++i) {
+    QByteArray sig = metaObject->method(i).methodSignature();
+    if (metaObject->indexOfSignal(sig) != -1) {
+      sig.prepend(QSIGNAL_CODE + '0');
+      connect(obj, sig, this, SLOT(printSignal()));
+    }
+  }
+}
+
+/**
+ * @brief Print emitted signal to debug output.
+ */
+void DebugUtils::SignalEmissionDumper::printSignal()
+{
+  if (QObject* obj = sender()) {
+    int idx = senderSignalIndex();
+    if (idx != -1) {
+      QByteArray sig = obj->metaObject()->method(idx).methodSignature();
+      if (!sig.isEmpty()) {
+        qDebug("SIGNAL OUT %s::%s %s",
+               obj->metaObject()->className(),
+               qPrintable(obj->objectName().isEmpty()
+                          ? QLatin1String("unnamed") : obj->objectName()),
+               sig.constData());
+      }
+    }
+  }
+}
+
 
 /**
  * Dump an item model.
@@ -72,18 +120,24 @@ void DebugUtils::dumpModel(const QAbstractItemModel& model,
       QModelIndex idx(model.index(row, column, parent));
       if (column > 0)
         rowStr += QLatin1String(",");
-      rowStr += QString(QLatin1String("%1%2:")).
-          arg(model.hasChildren(idx) ? QLatin1String("p") : QLatin1String("")).
-          arg(column);
+      rowStr += QString(QLatin1String("%1%2:"))
+          .arg(model.hasChildren(idx) ? QLatin1String("p") : QLatin1String(""))
+          .arg(column);
       rowStr += model.data(idx).toString();
       if (model.hasChildren(idx))
         indexesWithChildren.append(idx);
     }
     qDebug("%s", qPrintable(rowStr));
-    foreach (const QModelIndex& idx, indexesWithChildren) {
+    const auto idxs = indexesWithChildren;
+    for (const QModelIndex& idx : idxs) {
       dumpModel(model, idx, indent + 2);
     }
   }
 }
 
+#else
+
+void DebugUtils::SignalEmissionDumper::connectObject(QObject*) {}
+void DebugUtils::SignalEmissionDumper::printSignal() {}
+
 #endif
