@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 2 Jan 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -37,16 +37,16 @@
  * Constructor.
  * @param parent parent widget
  */
-BatchImportSourceDialog::BatchImportSourceDialog(QWidget* parent) :
-  QDialog(parent)
+BatchImportSourceDialog::BatchImportSourceDialog(QWidget* parent)
+  : QDialog(parent)
 {
   setObjectName(QLatin1String("BatchImportSourceDialog"));
   setWindowTitle(tr("Import Source"));
   setSizeGripEnabled(true);
 
-  QVBoxLayout* vlayout = new QVBoxLayout(this);
+  auto vlayout = new QVBoxLayout(this);
 
-  QHBoxLayout* serverLayout = new QHBoxLayout;
+  auto serverLayout = new QHBoxLayout;
   QLabel* serverLabel = new QLabel(tr("&Server:"));
   serverLayout->addWidget(serverLabel);
   m_serverComboBox = new QComboBox;
@@ -54,7 +54,7 @@ BatchImportSourceDialog::BatchImportSourceDialog(QWidget* parent) :
   serverLayout->addWidget(m_serverComboBox);
   vlayout->addLayout(serverLayout);
 
-  QHBoxLayout* accuracyLayout = new QHBoxLayout;
+  auto accuracyLayout = new QHBoxLayout;
   QLabel* accuracyLabel = new QLabel(tr("&Accuracy:"));
   accuracyLayout->addWidget(accuracyLabel);
   m_accuracySpinBox = new QSpinBox;
@@ -64,7 +64,7 @@ BatchImportSourceDialog::BatchImportSourceDialog(QWidget* parent) :
   accuracyLayout->addWidget(m_accuracySpinBox);
   vlayout->addLayout(accuracyLayout);
 
-  QHBoxLayout* tagsCoverLayout = new QHBoxLayout;
+  auto tagsCoverLayout = new QHBoxLayout;
   m_standardTagsCheckBox = new QCheckBox(tr("&Standard Tags"));
   m_standardTagsCheckBox->setChecked(true);
   m_additionalTagsCheckBox = new QCheckBox(tr("&Additional Tags"));
@@ -78,18 +78,11 @@ BatchImportSourceDialog::BatchImportSourceDialog(QWidget* parent) :
 
   QDialogButtonBox* buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok |
                                                      QDialogButtonBox::Cancel);
-  connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-  connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+  connect(buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+  connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
   vlayout->addWidget(buttonBox);
 }
 
-/**
- * Destructor.
- */
-BatchImportSourceDialog::~BatchImportSourceDialog()
-{
-}
-
 /**
  * Set names of import servers.
  * @param servers server names
