@@ -35,6 +35,7 @@
 #include <QTabWidget>
 #include <QListView>
 #include <QSpinBox>
+#include <QToolBox>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QFormLayout>
@@ -143,6 +144,7 @@ ConfigDialogPages::ConfigDialogPages(IPlatformTools* platformTools,
   m_id3v2VersionComboBox(nullptr), m_trackNumberDigitsSpinBox(nullptr),
   m_fnFormatBox(nullptr), m_tagFormatBox(nullptr),
   m_onlyCustomGenresCheckBox(nullptr), m_genresEditModel(nullptr),
+  m_customFramesEditModel(nullptr),
   m_quickAccessTagsModel(nullptr), m_starRatingMappingsModel(nullptr),
   m_trackNameComboBox(nullptr), m_playOnDoubleClickCheckBox(nullptr),
   m_commandsTable(nullptr), m_commandsTableModel(nullptr),
@@ -275,21 +277,35 @@ QWidget* ConfigDialogPages::createTagsPage()
   tag2Layout->addLayout(tag2LeftLayout);
 
   auto tag2RightLayout = new QVBoxLayout;
-  QGroupBox* genresGroupBox = new QGroupBox(tr("Custom &Genres"), tag2Page);
+  QToolBox* tag2RightToolBox = new QToolBox;
+
+  QWidget* genresWidget = new QWidget;
   m_onlyCustomGenresCheckBox = new QCheckBox(tr("&Show only custom genres"),
-                                             genresGroupBox);
-  m_genresEditModel = new QStringListModel(genresGroupBox);
-  auto genresEdit = new StringListEdit(m_genresEditModel, genresGroupBox);
+                                             genresWidget);
+  m_genresEditModel = new QStringListModel(genresWidget);
+  auto genresEdit = new StringListEdit(m_genresEditModel, genresWidget);
   auto vbox = new QVBoxLayout;
   vbox->addWidget(m_onlyCustomGenresCheckBox);
   vbox->addWidget(genresEdit);
-  genresGroupBox->setLayout(vbox);
-  tag2RightLayout->addWidget(genresGroupBox);
+  genresWidget->setLayout(vbox);
+  tag2RightToolBox->addItem(genresWidget, tr("Cu&stom Genres"));
 
-  QGroupBox* quickAccessTagsGroupBox = new QGroupBox(tr("&Quick Access Frames"));
-  auto quickAccessTagsLayout = new QVBoxLayout(quickAccessTagsGroupBox);
+  QWidget* customFramesWidget = new QWidget;
+  m_customFramesEditModel = new QStringListModel(customFramesWidget);
+  connect(m_customFramesEditModel, &QStringListModel::dataChanged,
+          this, &ConfigDialogPages::onCustomFramesEditModelChanged);
+  connect(m_customFramesEditModel, &QStringListModel::rowsRemoved,
+          this, &ConfigDialogPages::onCustomFramesEditModelChanged);
+  auto customFramesEdit = new StringListEdit(m_customFramesEditModel, customFramesWidget);
+  auto customFramesVBox = new QVBoxLayout;
+  customFramesVBox->addWidget(customFramesEdit);
+  customFramesWidget->setLayout(customFramesVBox);
+  tag2RightToolBox->addItem(customFramesWidget, tr("Custom F&rames"));
+
+  QWidget* quickAccessWidget = new QWidget;
+  auto quickAccessTagsLayout = new QVBoxLayout(quickAccessWidget);
   auto quickAccessTagsListView = new QListView;
-  m_quickAccessTagsModel = new QStandardItemModel(quickAccessTagsGroupBox);
+  m_quickAccessTagsModel = new QStandardItemModel(quickAccessWidget);
   quickAccessTagsListView->setModel(m_quickAccessTagsModel);
   quickAccessTagsListView->setAcceptDrops(true);
   quickAccessTagsListView->setDragEnabled(true);
@@ -302,7 +318,9 @@ QWidget* ConfigDialogPages::createTagsPage()
       new QLabel(tr("Use drag and drop to reorder the items"));
   reorderLabel->setWordWrap(true);
   quickAccessTagsLayout->addWidget(reorderLabel);
-  tag2RightLayout->addWidget(quickAccessTagsGroupBox);
+  tag2RightToolBox->addItem(quickAccessWidget, tr("&Quick Access Frames"));
+  tag2RightToolBox->setCurrentWidget(quickAccessWidget);
+  tag2RightLayout->addWidget(tag2RightToolBox);
   tag2Layout->addLayout(tag2RightLayout);
 
   QWidget* tag3Page = new QWidget;
@@ -438,7 +456,7 @@ QWidget* ConfigDialogPages::createFilesPage()
 
   QString fnFormatTitle(tr("&Filename Format"));
   m_fnFormatBox = new FilenameFormatBox(fnFormatTitle, filesPage);
-  vlayout->addWidget(m_fnFormatBox);
+  vlayout->addWidget(m_fnFormatBox, 1);
   return filesPage;
 }
 
@@ -656,29 +674,10 @@ void ConfigDialogPages::setConfigs(
   m_fromFilenameFormats = fileCfg.fromFilenameFormats();
   m_onlyCustomGenresCheckBox->setChecked(tagCfg.onlyCustomGenres());
   m_genresEditModel->setStringList(tagCfg.customGenres());
+  m_customFramesEditModel->setStringList(
+        TagConfig::customFrameNamesToDisplayNames(tagCfg.customFrames()));
   m_starRatingMappingsModel->setMappings(tagCfg.starRatingMappings());
-  quint64 frameMask = tagCfg.quickAccessFrames();
-  QList<int> frameTypes = tagCfg.quickAccessFrameOrder();
-  if (frameTypes.size() != Frame::FT_LastFrame + 1) {
-    frameTypes.clear();
-    frameTypes.reserve(Frame::FT_LastFrame - Frame::FT_FirstFrame + 1);
-    for (int i = Frame::FT_FirstFrame; i <= Frame::FT_LastFrame; ++i) {
-      frameTypes.append(i);
-    }
-  }
-  m_quickAccessTagsModel->clear();
-  const auto constFrameTypes = frameTypes;
-  for (int frameType : constFrameTypes) {
-    QStandardItem* item = new QStandardItem(
-          Frame::ExtendedType(static_cast<Frame::Type>(frameType))
-          .getTranslatedName());
-    item->setData(frameType, Qt::UserRole);
-    item->setCheckable(true);
-    item->setCheckState((frameMask & (1ULL << frameType))
-                        ? Qt::Checked : Qt::Unchecked);
-    item->setDropEnabled(false);
-    m_quickAccessTagsModel->appendRow(item);
-  }
+  setQuickAccessFramesConfig(tagCfg.quickAccessFrameOrder(), tagCfg.quickAccessFrames());
   m_commandsTableModel->setCommandList(userActionsCfg.contextMenuCommands());
   int idx = m_commentNameComboBox->findText(tagCfg.commentName());
   if (idx >= 0) {
@@ -795,27 +794,12 @@ void ConfigDialogPages::getConfig() const
   fileCfg.setFromFilenameFormats(m_fromFilenameFormats);
   tagCfg.setOnlyCustomGenres(m_onlyCustomGenresCheckBox->isChecked());
   tagCfg.setCustomGenres(m_genresEditModel->stringList());
+  tagCfg.setCustomFrames(TagConfig::customFrameNamesFromDisplayNames(
+                           m_customFramesEditModel->stringList()));
   tagCfg.setStarRatingMappings(m_starRatingMappingsModel->getMappings());
   QList<int> frameTypes;
-  bool isStandardFrameOrder = true;
   quint64 frameMask = 0;
-  const int numQuickAccessTags = m_quickAccessTagsModel->rowCount();
-  frameTypes.reserve(numQuickAccessTags);
-  for (int row = 0; row < numQuickAccessTags; ++row) {
-    QModelIndex index = m_quickAccessTagsModel->index(row, 0);
-    int frameType = index.data(Qt::UserRole).toInt();
-    if (frameType != row) {
-      isStandardFrameOrder = false;
-    }
-    frameTypes.append(frameType);
-    if (m_quickAccessTagsModel->data(
-          index, Qt::CheckStateRole).toInt() == Qt::Checked) {
-      frameMask |= 1ULL << frameType;
-    }
-  }
-  if (isStandardFrameOrder) {
-    frameTypes.clear();
-  }
+  getQuickAccessFramesConfig(frameTypes, frameMask);
   tagCfg.setQuickAccessFrames(frameMask);
   tagCfg.setQuickAccessFrameOrder(frameTypes);
   userActionsCfg.setContextMenuCommands(m_commandsTableModel->getCommandList());
@@ -869,3 +853,51 @@ void ConfigDialogPages::getConfig() const
     guiCfg.setConfigWindowGeometry(configDialog->saveGeometry());
   }
 }
+
+void ConfigDialogPages::onCustomFramesEditModelChanged()
+{
+  QList<int> frameTypes;
+  quint64 frameMask = 0;
+  getQuickAccessFramesConfig(frameTypes, frameMask);
+  setQuickAccessFramesConfig(frameTypes, frameMask);
+}
+
+void ConfigDialogPages::getQuickAccessFramesConfig(QList<int>& frameTypes,
+                                                   quint64& frameMask) const
+{
+  const int numQuickAccessTags = m_quickAccessTagsModel->rowCount();
+  QVariantList namesSelected;
+  namesSelected.reserve(numQuickAccessTags);
+  for (int row = 0; row < numQuickAccessTags; ++row) {
+    QModelIndex index = m_quickAccessTagsModel->index(row, 0);
+    auto name = index.data().toString();
+    auto frameType = index.data(Qt::UserRole).toInt();
+    auto selected = m_quickAccessTagsModel->data(
+          index, Qt::CheckStateRole).toInt() == Qt::Checked;
+    namesSelected.append(
+          QVariantMap{{QLatin1String("name"), name},
+                      {QLatin1String("type"), frameType},
+                      {QLatin1String("selected"), selected}});
+  }
+  TagConfig::setQuickAccessFrameSelection(namesSelected, frameTypes, frameMask);
+}
+
+void ConfigDialogPages::setQuickAccessFramesConfig(const QList<int>& types,
+                                                   quint64 frameMask)
+{
+  const QVariantList namesSelected = TagConfig::getQuickAccessFrameSelection(
+        types, frameMask, m_customFramesEditModel->stringList());
+  m_quickAccessTagsModel->clear();
+  for (const QVariant& var : namesSelected) {
+    auto map = var.toMap();
+    auto name = map.value(QLatin1String("name")).toString();
+    auto frameType = map.value(QLatin1String("type")).toInt();
+    auto selected = map.value(QLatin1String("selected")).toBool();
+    QStandardItem* item = new QStandardItem(name);
+    item->setData(frameType, Qt::UserRole);
+    item->setCheckable(true);
+    item->setCheckState(selected ? Qt::Checked : Qt::Unchecked);
+    item->setDropEnabled(false);
+    m_quickAccessTagsModel->appendRow(item);
+  }
+}
