@@ -50,6 +50,7 @@ class PictureLabel;
 class BaseMainWindowImpl;
 class Kid3FormTagContext;
 class AbstractFileDecorationProvider;
+class SectionActions;
 
 /**
  * Main widget.
@@ -72,6 +73,12 @@ public:
    */
   virtual ~Kid3Form() override;
 
+  /**
+   * Set keyboard shortcuts for section actions.
+   * @param map map of action names to key sequences
+   */
+  void setSectionActionShortcuts(const QMap<QString, QKeySequence>& map);
+
   /**
    * Get context for tag.
    * @param tagNr tag number
@@ -137,6 +144,16 @@ public:
    */
   void readConfig();
 
+  /**
+   * Save file and directory list columns to the configuration.
+   */
+  void saveFileAndDirListConfig();
+
+  /**
+   * Set file and directory list columns from the configuration.
+   */
+  void readFileAndDirListConfig();
+
   /**
    * Get filename.
    */
@@ -237,6 +254,20 @@ public slots:
    */
   void dirSelected(const QModelIndex& index);
 
+  /**
+   * File list box item activated.
+   *
+   * @param index selected item
+   */
+  void fileActivated(const QModelIndex& index);
+
+  /**
+   * Open the parent directory of a model index.
+   *
+   * @param index current root index of item view
+   */
+  void openParentDirectory(const QModelIndex& index);
+
   /**
    * Set focus on filename controls.
    */
@@ -248,6 +279,18 @@ public slots:
    */
   void setFocusTag(Frame::TagNumber tagNr);
 
+  /**
+   * Set focus on next tag controls.
+   * @param tagNr current tag, Frame::Tag_NumValues if not on tag
+   */
+  void setFocusNextTag(Frame::TagNumber tagNr);
+
+  /**
+   * Set focus on previous tag controls.
+   * @param tagNr current tag, Frame::Tag_NumValues if not on tag
+   */
+  void setFocusPreviousTag(Frame::TagNumber tagNr);
+
   /**
    * Set focus on file list.
    */
@@ -432,6 +475,7 @@ private:
   Kid3Application* m_app;
   BaseMainWindowImpl* m_mainWin;
   QScopedPointer<AbstractFileDecorationProvider> m_iconProvider;
+  QList<SectionActions*> m_sectionActions;
 
   /** Collapse pixmap, will be allocated in constructor */
   static QPixmap* s_collapsePixmap;
