@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 2 Jan 2013
  *
- * Copyright (C) 2013  Urs Fleisch
+ * Copyright (C) 2013-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -37,16 +37,16 @@
  * @param parent parent widget
  */
 AbstractListEdit::AbstractListEdit(QAbstractItemView* itemView,
-                                   QAbstractItemModel* model, QWidget* parent) :
-  QWidget(parent)
+                                   QAbstractItemModel* model, QWidget* parent)
+  : QWidget(parent)
 {
   setObjectName(QLatin1String("AbstractListEdit"));
-  QHBoxLayout* hlayout = new QHBoxLayout(this);
+  auto hlayout = new QHBoxLayout(this);
   m_itemView = itemView;
   m_itemView->setModel(model);
   hlayout->setContentsMargins(0, 0, 0, 0);
   hlayout->addWidget(m_itemView);
-  QVBoxLayout* vlayout = new QVBoxLayout;
+  auto vlayout = new QVBoxLayout;
   m_addPushButton = new QPushButton(tr("&Add..."), this);
   m_moveUpPushButton = new QPushButton(tr("Move &Up"), this);
   m_moveDownPushButton = new QPushButton(tr("Move &Down"), this);
@@ -59,26 +59,19 @@ AbstractListEdit::AbstractListEdit(QAbstractItemView* itemView,
   vlayout->addWidget(m_removePushButton);
   vlayout->addStretch();
 
-  connect(m_addPushButton, SIGNAL(clicked()), this, SLOT(addItem()));
-  connect(m_moveUpPushButton, SIGNAL(clicked()), this, SLOT(moveUpItem()));
-  connect(m_moveDownPushButton, SIGNAL(clicked()), this, SLOT(moveDownItem()));
-  connect(m_editPushButton, SIGNAL(clicked()), this, SLOT(editItem()));
-  connect(m_removePushButton, SIGNAL(clicked()), this, SLOT(removeItem()));
+  connect(m_addPushButton, &QAbstractButton::clicked, this, &AbstractListEdit::addItem);
+  connect(m_moveUpPushButton, &QAbstractButton::clicked, this, &AbstractListEdit::moveUpItem);
+  connect(m_moveDownPushButton, &QAbstractButton::clicked, this, &AbstractListEdit::moveDownItem);
+  connect(m_editPushButton, &QAbstractButton::clicked, this, &AbstractListEdit::editItem);
+  connect(m_removePushButton, &QAbstractButton::clicked, this, &AbstractListEdit::removeItem);
   connect(m_itemView->selectionModel(),
-          SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-          this, SLOT(setButtonEnableState()));
+          &QItemSelectionModel::currentChanged,
+          this, &AbstractListEdit::setButtonEnableState);
 
   setButtonEnableState();
   hlayout->addLayout(vlayout);
 }
 
-/**
- * Destructor.
- */
-AbstractListEdit::~AbstractListEdit()
-{
-}
-
 /**
  * Disable editing of items.
  * When editing is disabled, the Add, Edit and Remove buttons are hidden.
@@ -91,6 +84,15 @@ void AbstractListEdit::setEditingDisabled(bool disable)
   m_removePushButton->setHidden(disable);
 }
 
+/**
+ * Set text for Add button.
+ * @param text button text
+ */
+void AbstractListEdit::setAddButtonText(const QString& text)
+{
+  m_addPushButton->setText(text);
+}
+
 /**
  * Remove the selected item.
  */
