@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 14 Mar 2014
  *
- * Copyright (C) 2014  Urs Fleisch
+ * Copyright (C) 2014-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef EVENTCODEDELEGATE_H
-#define EVENTCODEDELEGATE_H
+#pragma once
 
 #include "enumdelegate.h"
 
@@ -38,19 +37,17 @@ public:
    * @brief Constructor.
    * @param parent parent object
    */
-  explicit EventCodeDelegate(QObject* parent = 0);
+  explicit EventCodeDelegate(QObject* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~EventCodeDelegate();
+  virtual ~EventCodeDelegate() override = default;
 
 protected:
   // Reimplemented from EnumDelegate.
-  virtual QStringList getEnumStrings() const;
-  virtual QString getStringForEnum(int enumNr) const;
-  virtual int getIndexForEnum(int enumNr) const;
-  virtual int getEnumForIndex(int index) const;
+  virtual QStringList getEnumStrings() const override;
+  virtual QString getStringForEnum(int enumNr) const override;
+  virtual int getIndexForEnum(int enumNr) const override;
+  virtual int getEnumForIndex(int index) const override;
 };
-
-#endif // EVENTCODEDELEGATE_H
