@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 18 Sep 2015
  *
- * Copyright (C) 2015  Urs Fleisch
+ * Copyright (C) 2015-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,8 +24,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef SUBFRAMESEDITOR_H
-#define SUBFRAMESEDITOR_H
+#pragma once
 
 #include <QWidget>
 #include "frame.h"
@@ -55,12 +54,12 @@ public:
    */
   explicit SubframesEditor(IPlatformTools* platformTools, Kid3Application* app,
                            const TaggedFile* taggedFile, Frame::TagNumber tagNr,
-                           QWidget* parent = 0);
+                           QWidget* parent = nullptr);
 
   /**
    * Destructor.
    */
-  virtual ~SubframesEditor();
+  virtual ~SubframesEditor() override = default;
 
   /**
    * Set subframes.
@@ -96,5 +95,3 @@ private:
   Frame m_editFrame;
   int m_editFrameRow;
 };
-
-#endif // SUBFRAMESEDITOR_H
