@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 13 Sep 2005
  *
- * Copyright (C) 2005-2013  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -32,8 +32,8 @@ int DiscogsConfig::s_index = -1;
 /**
  * Constructor.
  */
-DiscogsConfig::DiscogsConfig() :
-  StoredConfig<DiscogsConfig, ServerImporterConfig>(QLatin1String("Discogs"))
+DiscogsConfig::DiscogsConfig()
+  : StoredConfig<DiscogsConfig, ServerImporterConfig>(QLatin1String("Discogs"))
 {
   setCgiPathUsed(false);
   setAdditionalTagsUsed(true);
@@ -43,4 +43,7 @@ DiscogsConfig::DiscogsConfig() :
 /**
  * Destructor.
  */
-DiscogsConfig::~DiscogsConfig() {}
+DiscogsConfig::~DiscogsConfig()
+{
+  // not inline or default to silence weak-vtables warning
+}
