@@ -194,6 +194,11 @@ QString getNameForType(Frame::Type type)
     auto it = typeNameMap.constFind(type);
     if (it != typeNameMap.constEnd()) {
       return *it;
+    } else {
+      auto customFrameName = Frame::getNameForCustomFrame(type);
+      if (!customFrameName.isEmpty()) {
+        return QString::fromLatin1(customFrameName);
+      }
     }
   }
   return QString();
@@ -220,7 +225,11 @@ Frame::Type getTypeForName(const QString& name, bool onlyPredefined = false)
     }
     auto it = nameTypeMap.constFind(name);
     if (it != nameTypeMap.constEnd()) {
-      return *it;
+      Frame::Type type = *it;
+      if (type == Frame::FT_Other) {
+        type = Frame::getTypeFromCustomFrameName(name.toLatin1());
+      }
+      return type;
     }
   }
   if (!onlyPredefined) {
@@ -236,7 +245,7 @@ Frame::Type getTypeForName(const QString& name, bool onlyPredefined = false)
     if (it != freeFormNameTypeMap.constEnd()) {
       return *it;
     }
-    return Frame::FT_Other;
+    return Frame::getTypeFromCustomFrameName(name.toLatin1());
   }
   return Frame::FT_UnknownFrame;
 }
@@ -376,7 +385,7 @@ QByteArray getValueByteArray(const char* name,
 /**
  * Constructor.
  *
- * @param idx index in file proxy model
+ * @param idx index in tagged file system model
  */
 M4aFile::M4aFile(const QPersistentModelIndex& idx)
   : TaggedFile(idx), m_fileRead(false)
