@@ -27,6 +27,7 @@
 #include "musicbrainzimporter.h"
 #include <QDomDocument>
 #include <QUrl>
+#include <QRegularExpression>
 #include "serverimporterconfig.h"
 #include "trackdatamodel.h"
 #include "musicbrainzconfig.h"
@@ -250,8 +251,9 @@ QString fixUpGenre(QString genre)
     return genre;
   }
   for (int i = 0; i < genre.length(); ++i) {
-    if (i == 0 || genre.at(i - 1) == '-' || genre.at(i - 1) == ' ' ||
-        genre.at(i - 1) == '&') {
+    if (i == 0 || genre.at(i - 1) == QLatin1Char('-') ||
+        genre.at(i - 1) == QLatin1Char(' ') ||
+        genre.at(i - 1) == QLatin1Char('&')) {
       genre[i] = genre[i].toUpper();
     }
   }
@@ -356,10 +358,11 @@ void MusicBrainzImporter::parseAlbumResults(const QByteArray& albumStr)
       }
       QString date(release.namedItem(QLatin1String("date")).toElement().text());
       if (!date.isEmpty()) {
-        QRegExp dateRe(QLatin1String(R"((\d{4})(?:-\d{2})?(?:-\d{2})?)"));
+        QRegularExpression dateRe(QLatin1String(R"(^(\d{4})(?:-\d{2})?(?:-\d{2})?$)"));
         int year = 0;
-        if (dateRe.exactMatch(date)) {
-          year = dateRe.cap(1).toInt();
+        auto match = dateRe.match(date);
+        if (match.hasMatch()) {
+          year = match.captured(1).toInt();
         } else {
           year = date.toInt();
         }
@@ -436,7 +439,7 @@ void MusicBrainzImporter::parseAlbumResults(const QByteArray& albumStr)
                         // https://www.amazon.de/gp/product/ does not work,
                         // fix such links.
                         coverArtUrl.replace(
-                            QRegExp(QLatin1String(
+                            QRegularExpression(QLatin1String(
                                   "https://www\\.amazon\\.[^/]+/gp/product/")),
                             QLatin1String("http://images.amazon.com/images/P/"));
                         if (!coverArtUrl.endsWith(QLatin1String(".jpg"))) {
