@@ -6,7 +6,7 @@
  * \author Urs Fleisch
  * \date 26 Sep 2005
  *
- * Copyright (C) 2005-2011  Urs Fleisch
+ * Copyright (C) 2005-2018  Urs Fleisch
  *
  * This file is part of Kid3.
  *
@@ -24,11 +24,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef OGGFILE_H
-#define OGGFILE_H
+#pragma once
 
-#include "oggflacconfig.h"
 #include <QList>
+#include "oggflacconfig.h"
 #include "taggedfile.h"
 
 
@@ -38,33 +37,33 @@ public:
   /**
    * Constructor.
    *
-   * @param idx index in file proxy model
+   * @param idx index in tagged file system model
    */
   explicit OggFile(const QPersistentModelIndex& idx);
 
   /**
    * Destructor.
    */
-  virtual ~OggFile();
+  virtual ~OggFile() override = default;
 
   /**
    * Get key of tagged file format.
    * @return "OggMetadata".
    */
-  virtual QString taggedFileKey() const;
+  virtual QString taggedFileKey() const override;
 
   /**
    * Get features supported.
    * @return bit mask with Feature flags set.
    */
-  virtual int taggedFileFeatures() const;
+  virtual int taggedFileFeatures() const override;
 
   /**
    * Read tags from file.
    *
    * @param force true to force reading even if tags were already read.
    */
-  virtual void readTags(bool force);
+  virtual void readTags(bool force) override;
 
   /**
    * Write tags to file and rename it if necessary.
@@ -77,14 +76,14 @@ public:
    *
    * @return true if ok, false if the file could not be written or renamed.
    */
-  virtual bool writeTags(bool force, bool* renamed, bool preserve);
+  virtual bool writeTags(bool force, bool* renamed, bool preserve) override;
 
   /**
    * Free resources allocated when calling readTags().
    *
    * @param force true to force clearing even if the tags are modified
    */
-  virtual void clearTags(bool force);
+  virtual void clearTags(bool force) override;
 
   /**
    * Remove frames.
@@ -92,7 +91,7 @@ public:
    * @param tagNr tag number
    * @param flt filter specifying which frames to remove
    */
-  virtual void deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt);
+  virtual void deleteFrames(Frame::TagNumber tagNr, const FrameFilter& flt) override;
 
 
   /**
@@ -102,7 +101,7 @@ public:
    *         false if the tags have not been read yet, in which case
    *         hasTag() does not return meaningful information.
    */
-  virtual bool isTagInformationRead() const;
+  virtual bool isTagInformationRead() const override;
 
   /**
    * Check if file has a tag.
@@ -111,14 +110,14 @@ public:
    * @return true if a tag is available.
    * @see isTagInformationRead()
    */
-  virtual bool hasTag(Frame::TagNumber tagNr) const;
+  virtual bool hasTag(Frame::TagNumber tagNr) const override;
 
   /**
    * Get technical detail information.
    *
    * @param info the detail information is returned here
    */
-  virtual void getDetailInfo(DetailInfo& info) const;
+  virtual void getDetailInfo(DetailInfo& info) const override;
 
   /**
    * Get duration of file.
@@ -126,14 +125,14 @@ public:
    * @return duration in seconds,
    *         0 if unknown.
    */
-  virtual unsigned getDuration() const;
+  virtual unsigned getDuration() const override;
 
   /**
    * Get file extension including the dot.
    *
    * @return file extension ".ogg".
    */
-  virtual QString getFileExtension() const;
+  virtual QString getFileExtension() const override;
 
   /**
    * Get the format of tag.
@@ -141,7 +140,7 @@ public:
    * @param tagNr tag number
    * @return "Vorbis".
    */
-  virtual QString getTagFormat(Frame::TagNumber tagNr) const;
+  virtual QString getTagFormat(Frame::TagNumber tagNr) const override;
 
   /**
    * Get a specific frame from the tags.
@@ -152,7 +151,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool getFrame(Frame::TagNumber tagNr, Frame::Type type, Frame& frame) const;
+  virtual bool getFrame(Frame::TagNumber tagNr, Frame::Type type, Frame& frame) const override;
 
   /**
    * Set a frame in the tags.
@@ -162,7 +161,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool setFrame(Frame::TagNumber tagNr, const Frame& frame);
+  virtual bool setFrame(Frame::TagNumber tagNr, const Frame& frame) override;
 
   /**
    * Add a frame in the tags.
@@ -172,7 +171,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool addFrame(Frame::TagNumber tagNr, Frame& frame);
+  virtual bool addFrame(Frame::TagNumber tagNr, Frame& frame) override;
 
   /**
    * Delete a frame in the tags.
@@ -182,7 +181,7 @@ public:
    *
    * @return true if ok.
    */
-  virtual bool deleteFrame(Frame::TagNumber tagNr, const Frame& frame);
+  virtual bool deleteFrame(Frame::TagNumber tagNr, const Frame& frame) override;
 
   /**
    * Get all frames in tag.
@@ -190,14 +189,14 @@ public:
    * @param tagNr tag number
    * @param frames frame collection to set.
    */
-  virtual void getAllFrames(Frame::TagNumber tagNr, FrameCollection& frames);
+  virtual void getAllFrames(Frame::TagNumber tagNr, FrameCollection& frames) override;
 
   /**
    * Get a list of frame IDs which can be added.
    * @param tagNr tag number
    * @return list with frame IDs.
    */
-  virtual QStringList getFrameIds(Frame::TagNumber tagNr) const;
+  virtual QStringList getFrameIds(Frame::TagNumber tagNr) const override;
 
 protected:
   /** Vorbis comment field. */
@@ -205,10 +204,8 @@ protected:
   public:
     /** Constructor. */
     CommentField(const QString& name = QString(),
-                 const QString& value = QString()) :
-      m_name(name), m_value(value) {}
-    /** Destructor. */
-    ~CommentField() {}
+                 const QString& value = QString())
+      : m_name(name), m_value(value) {}
     /**
      * Get name.
      * @return name.
@@ -310,5 +307,3 @@ private:
   bool readFileInfo(FileInfo& info, const QString& fn) const;
 #endif // HAVE_VORBIS
 };
-
-#endif // OGGFILE_H
