@@ -27,7 +27,6 @@
 #pragma once
 
 #include <QtGlobal>
-#include "taglibconfig.h"
 #include "taggedfile.h"
 #include "tagconfig.h"
 #include <taglib.h>
@@ -41,13 +40,11 @@
 class QTextCodec;
 class FileIOStream;
 
-#ifdef TAGLIB_WITH_MP4
   namespace TagLib {
     namespace MP4 {
       class Tag;
     }
   }
-#endif
 
 class TagLibFile;
 
@@ -64,7 +61,7 @@ public:
   /**
    * Constructor.
    *
-   * @param idx index in file proxy model
+   * @param idx index in tagged file system model
    */
   explicit TagLibFile(const QPersistentModelIndex& idx);
 
@@ -384,14 +381,12 @@ private:
    */
   QString getVorbisName(const Frame& frame) const;
 
-#ifdef TAGLIB_WITH_MP4
   /**
    * Set a frame in an MP4 tag.
    * @param frame frame to set
    * @param mp4Tag MP4 tag
    */
   void setMp4Frame(const Frame& frame, TagLib::MP4::Tag* mp4Tag);
-#endif
 
   /**
    * Get the format of a tag.
@@ -406,11 +401,11 @@ private:
   static QString getTagFormat(const TagLib::Tag* tag, TagType& type);
 
   /**
-   * Set the text codec to be used for tag 1.
+   * Set the encoding to be used for tag 1.
    *
-   * @param codec text codec, 0 to use default (ISO 8859-1)
+   * @param name of encoding, default is ISO 8859-1
    */
-  static void setTextCodecV1(const QTextCodec* codec);
+  static void setTextEncodingV1(const QString& name);
 
   /**
    * Set the default text encoding.
