@@ -5,8 +5,8 @@
 
 BASEDIR="../src" # root of translatable sources
 PROJECT="kid3" # project name
-PROJECTVERSION="3.8.2" # project version
-BUGADDR="http://sourceforge.net/p/kid3/bugs/" # MSGID-Bugs
+PROJECTVERSION="3.9.1" # project version
+BUGADDR="https://bugs.kde.org" # MSGID-Bugs
 WDIR=`pwd` # working dir
 
 # Use extract-merge.sh if found in the path, its from
@@ -21,6 +21,10 @@ elif hash extract-messages.sh 2>/dev/null; then
   cd -
   mkdir -p po
   mv ../po/* po
+  if test -f ../enpo/kid3_qt.po; then
+    mkdir -p po/en
+    mv ../enpo/kid3_qt.po po/en/
+  fi
   rmdir ../po ../enpo
 else
   echo "extract-messages.sh not found in path, falling back to custom extraction"
@@ -57,7 +61,9 @@ fi
 echo "Merging translations"
 CATALOGS=`find po -name '*.po'`
 for CAT in $CATALOGS; do
-  echo $CAT
-  msgmerge --quiet --update --backup=none $CAT po/${PROJECT}_qt.pot
+  if test "$CAT" != "po/en/kid3_qt.po"; then
+    echo $CAT
+    msgmerge --quiet --update --backup=none $CAT po/${PROJECT}_qt.pot
+  fi
 done
 echo "Done"
